#
# spec file for package python-hunter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-hunter
Version:        3.7.0
Release:        1.1
Summary:        Pytest plugin for coverage reporting
License:        BSD-2-Clause
URL:            https://github.com/ionelmc/python-hunter
Source:         https://files.pythonhosted.org/packages/source/h/hunter/hunter-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
Hunter is a flexible code tracing toolkit, not for measuring coverage,
but for debugging, logging, inspection and other nefarious purposes.

%prep
%autosetup -p1 -n hunter-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}/
%python_clone -a %{buildroot}%{_bindir}/hunter-trace

%check

%post
%python_install_alternative hunter-trace

%postun
%python_uninstall_alternative hunter-trace

%files %{python_files}
%python_alternative %{_bindir}/hunter-trace
%license LICENSE
%doc AUTHORS.rst CHANGELOG.rst README.rst
%{python_sitearch}/*

%changelog
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 3.7.0:
  * Drop support for Python 3.7.
  * Upgrade linters and refactor various string formatting and
    other cleanups.
  * Upgrade Cython to latest release (3.0.10).
  * Linux wheels should be back now.
  * Switched docs theme to furo.
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 3.6.1:
  * Added safe repr support for Decimal objects.
  * Added C extension support for Python 3.11. This may come with
    up to 10%% performance hit (depending on use-case) for all
    Pythons.
  * Added safe repr support for ZoneInfo objects.
  * C extension files are now prebuilt with Cython 3.0b2.
  * Replaced the flake8/isort pre-commit hooks with ruff.
  * Disabled editable wheels
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.5.1
  * Fixed breakage in hunter-trace when Ctrl-C.
* Tue Oct 11 2022 pgajdos@suse.com
- version update to 3.5.0
  3.5.0 (2022-09-11)
  * Add support for generators and coroutines in the :obj:`hunter.wrap` decorator.
  * Dropped support for Python 3.6.
  3.4.3 (2021-12-15)
  * Removed most of the Python 2 support code.
  * Fix some refactoring regression in ``setup.py`` and make the 3.4.x series installable only on Python 3.6 and later.
  * Yank 3.4.0, 3.4.1, 3.4.2 releases to avoid install problems on Python 2.7.
  3.4.2 (2021-12-15)
  * Fixed CI to properly make win32 wheels.
  3.4.1 (2021-12-14)
  * Add support for building a ``pp37.pp38`` tagged wheel
    (basically an universal wheel installable just for those two PyPy versions).
  3.4.0 (2021-12-14)
  * Switched CI to GitHub Actions, this has a couple consequences:
  * Support for Python 2.7 is dropped. You can still install it there but it's not tested anymore and
    Python 2 specific handling will be removed at some point.
  * Linux wheels are now provided in `musllinux` and `manylinux2014` variants.
  * Extension building is now completely skipped on PyPy.
  * A pure but tagged as platform specific wheel is now provided for PyPy (to have fast installs there as well).
- deleted patches
  - deps.patch (upstreamed)
- does not require python-six
* Wed Nov 10 2021 Ondřej Súkup <mimi.vx@gmail.com>
- initital package
- add deps.patch
- tests for now broken in our envv
